@@ -190,8 +190,6 @@ class BitmexOrder:
                     self.props[symbol]['qty'] = 0
                     print("Short Position {} closed. {} Contracts from {} to {}. PnL in Points: {}".format(symbol,
                                                                                                            -self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, cp-self.props[symbol]['entry'])), flush=True)
-                else:
-                    self.props[symbol]['open'] = False
 
     def generate_id(self, symbol, _type='stop'):
         return "{}_{}_{}_{}".format(self.magic, symbol, str(uuid.uuid4().fields[-1])[:5], _type)
@@ -283,7 +281,6 @@ class BitmexOrder:
             time.sleep(5)
             stoploss = self.stoploss_order(symbol)
             self.props[symbol]['qty'] = orderQty
-            self.props[symbol]['open'] = True
             return entry, stoploss
         except HTTPBadRequest as e:
             print("Error placing bracket market order in {}.".format(
@@ -296,14 +293,16 @@ class BitmexOrder:
             ).result()
             self.props[symbol]['qty'] = orderQty
             self.props[symbol]['open'] = True
+            self.props[symbol]['wait_stop'] = False
             return order_res
         except HTTPBadRequest as e:
             print("Error placing market order.", e, flush=True)
 
     def modifiy_stop(self, symbol, newPrice):
         try:
+            # could be clOrdID, not sure difference
             res = self.client.client.Order.Order_amend(
-                orderID=self.props[symbol]['stoploss_id'], stopPx=self.price_decimals(symbol,
+                origClOrdID=self.props[symbol]['stoploss_id'], stopPx=self.price_decimals(symbol,
                                                                                         newPrice)
             ).result()
             return res
